@@ -1,3 +1,7 @@
+package Test::Environment::Plugin::Apache2::Apache2::Filter;
+
+1;
+
 package Apache2::Filter;
 
 =head1 NAME
